import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import Pages from 'vite-plugin-pages'
import Layouts from 'vite-plugin-vue-layouts'
import path from 'path'
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers'

// https://vitejs.dev/config/
export default defineConfig({
  plugins: [
    vue(),
    Pages({
      dirs: [
        { dir: 'src/page', baseRoute: '' },
        { dir: 'src/views', baseRoute: '' }
      ],
      exclude: ['**/components/*.vue'] // 排除组件
    }),
    Layouts({
      layoutsDirs: 'src/layout',
      defaultLayout: 'index'
    }),
    AutoImport({
      resolvers: [ElementPlusResolver()]
    }),
    Components({
      dts: true,
      resolvers: [ElementPlusResolver()]
    })
  ],
  resolve: {
    alias: {
      '@': path.resolve(path.resolve(), 'src')
    }
  },
  minify: 'terser',
  // css: {
  //   postcss: {
  //     plugins: [
  //       postCssPxToViewport({
  //         unitToConvert: 'px', // 要转化的单位
  //         viewportWidth: 1920, // UI设计稿的宽度
  //         unitPrecision: 6, // 转换后的精度，即小数点位数
  //         propList: ['*'], // 指定转换的css属性的单位，*代表全部css属性的单位都进行转换
  //         viewportUnit: 'vw', // 指定需要转换成的视窗单位，默认vw
  //         fontViewportUnit: 'vw', // 指定字体需要转换成的视窗单位，默认vw
  //         selectorBlackList: ['wrap'], // 指定不转换为视窗单位的类名，
  //         minPixelValue: 1, // 默认值1，小于或等于1px则不进行转换
  //         mediaQuery: true, // 是否在媒体查询的css代码中也进行转换，默认false
  //         replace: true, // 是否转换后直接更换属性值
  //         landscape: false // 是否处理横屏情况
  //       })
  //     ]
  //   }
  // },
  server: {
    open: true,
    proxy: {
      '/api': {
        // 正式环境地址
        // target: 'https://dev.wutongresearch.club/api',
        target: 'http://192.168.31.181:8110',
        changeOrigin: true,
        rewrite: path => path.replace(/^\/api/, '')
      }
    }
  }
})
